#[non_exhaustive]pub enum MaxLimit {
MaxNodes(i32),
MaxProcessingUnits(i32),
}Expand description
The maximum compute capacity for the instance. The maximum compute capacity should be less than or equal to 10X the minimum compute capacity.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MaxNodes(i32)
Maximum number of nodes allocated to the instance. If set, this number should be greater than or equal to min_nodes.
MaxProcessingUnits(i32)
Maximum number of processing units allocated to the instance. If set, this number should be multiples of 1000 and be greater than or equal to min_processing_units.