#[non_exhaustive]pub enum ExpireBehavior {
Unspecified,
FreeToProvisioned,
RemoveAfterGracePeriod,
UnknownValue(UnknownValue),
}Expand description
Allows users to change behavior when a free instance expires.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Not specified.
FreeToProvisioned
When the free instance expires, upgrade the instance to a provisioned instance.
RemoveAfterGracePeriod
When the free instance expires, disable the instance, and delete it after the grace period passes if it has not been upgraded.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ExpireBehavior::value or ExpireBehavior::name.
Implementations