#[non_exhaustive]pub enum ComputeCapacity {
NodeCount(i32),
ProcessingUnits(i32),
}Expand description
Compute capacity defines amount of server and storage resources that are
available to the databases in an instance partition. At most, one of either
node_count or processing_units should be present in the message. For
more information, see
Compute capacity, nodes, and processing
units.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
NodeCount(i32)
The number of nodes allocated to this instance partition.
Users can set the node_count field to specify the target number of
nodes allocated to the instance partition.
This may be zero in API responses for instance partitions that are not
yet in state READY.
ProcessingUnits(i32)
The number of processing units allocated to this instance partition.
Users can set the processing_units field to specify the target number
of processing units allocated to the instance partition.
This might be zero in API responses for instance partitions that are not
yet in the READY state.