#[non_exhaustive]pub struct FreeInstanceMetadata {
pub expire_time: Option<Timestamp>,
pub upgrade_time: Option<Timestamp>,
pub expire_behavior: ExpireBehavior,
/* private fields */
}Expand description
Free instance specific metadata that is kept even after an instance has been upgraded for tracking purposes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.expire_time: Option<Timestamp>Output only. Timestamp after which the instance will either be upgraded or scheduled for deletion after a grace period. ExpireBehavior is used to choose between upgrading or scheduling the free instance for deletion. This timestamp is set during the creation of a free instance.
upgrade_time: Option<Timestamp>Output only. If present, the timestamp at which the free instance was upgraded to a provisioned instance.
expire_behavior: ExpireBehaviorSpecifies the expiration behavior of a free instance. The default of
ExpireBehavior is REMOVE_AFTER_GRACE_PERIOD. This can be modified during
or after creation, and before expiration.
Implementations
Sourceimpl FreeInstanceMetadata
impl FreeInstanceMetadata
Sourcepub fn set_expire_time<T>(self, v: T) -> Self
pub fn set_expire_time<T>(self, v: T) -> Self
Sets the value of expire_time.
Example
use wkt::Timestamp;
let x = FreeInstanceMetadata::new().set_expire_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_expire_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_expire_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of expire_time.
Example
use wkt::Timestamp;
let x = FreeInstanceMetadata::new().set_or_clear_expire_time(Some(Timestamp::default()/* use setters */));
let x = FreeInstanceMetadata::new().set_or_clear_expire_time(None::<Timestamp>);Sourcepub fn set_upgrade_time<T>(self, v: T) -> Self
pub fn set_upgrade_time<T>(self, v: T) -> Self
Sets the value of upgrade_time.
Example
use wkt::Timestamp;
let x = FreeInstanceMetadata::new().set_upgrade_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_upgrade_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_upgrade_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of upgrade_time.
Example
use wkt::Timestamp;
let x = FreeInstanceMetadata::new().set_or_clear_upgrade_time(Some(Timestamp::default()/* use setters */));
let x = FreeInstanceMetadata::new().set_or_clear_upgrade_time(None::<Timestamp>);Sourcepub fn set_expire_behavior<T: Into<ExpireBehavior>>(self, v: T) -> Self
pub fn set_expire_behavior<T: Into<ExpireBehavior>>(self, v: T) -> Self
Sets the value of expire_behavior.
Example
use google_cloud_spanner_admin_instance_v1::model::free_instance_metadata::ExpireBehavior;
let x0 = FreeInstanceMetadata::new().set_expire_behavior(ExpireBehavior::FreeToProvisioned);
let x1 = FreeInstanceMetadata::new().set_expire_behavior(ExpireBehavior::RemoveAfterGracePeriod);Trait Implementations
Sourceimpl Clone for FreeInstanceMetadata
impl Clone for FreeInstanceMetadata
Sourcefn clone(&self) -> FreeInstanceMetadata
fn clone(&self) -> FreeInstanceMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for FreeInstanceMetadata
impl Debug for FreeInstanceMetadata
Sourceimpl Default for FreeInstanceMetadata
impl Default for FreeInstanceMetadata
Sourcefn default() -> FreeInstanceMetadata
fn default() -> FreeInstanceMetadata
Sourceimpl Message for FreeInstanceMetadata
impl Message for FreeInstanceMetadata
Sourceimpl PartialEq for FreeInstanceMetadata
impl PartialEq for FreeInstanceMetadata
impl StructuralPartialEq for FreeInstanceMetadata