#[non_exhaustive]pub struct ListInstancePartitionsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub instance_partition_deadline: Option<Timestamp>,
/* private fields */
}Expand description
The request for ListInstancePartitions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The instance whose instance partitions should be listed. Values
are of the form projects/<project>/instances/<instance>. Use {instance} = '-' to list instance partitions for all Instances in a project, e.g.,
projects/myproject/instances/-.
page_size: i32Number of instance partitions to be returned in the response. If 0 or less, defaults to the server’s maximum allowed page size.
page_token: StringIf non-empty, page_token should contain a
next_page_token
from a previous
ListInstancePartitionsResponse.
instance_partition_deadline: Option<Timestamp>Optional. Deadline used while retrieving metadata for instance partitions. Instance partitions whose metadata cannot be retrieved within this deadline will be added to unreachable in ListInstancePartitionsResponse.
Implementations
Sourceimpl ListInstancePartitionsRequest
impl ListInstancePartitionsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListInstancePartitionsRequest::new().set_page_token("example");Sourcepub fn set_instance_partition_deadline<T>(self, v: T) -> Self
pub fn set_instance_partition_deadline<T>(self, v: T) -> Self
Sets the value of instance_partition_deadline.
Example
use wkt::Timestamp;
let x = ListInstancePartitionsRequest::new().set_instance_partition_deadline(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_instance_partition_deadline<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_instance_partition_deadline<T>(self, v: Option<T>) -> Self
Sets or clears the value of instance_partition_deadline.
Example
use wkt::Timestamp;
let x = ListInstancePartitionsRequest::new().set_or_clear_instance_partition_deadline(Some(Timestamp::default()/* use setters */));
let x = ListInstancePartitionsRequest::new().set_or_clear_instance_partition_deadline(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for ListInstancePartitionsRequest
impl Clone for ListInstancePartitionsRequest
Sourcefn clone(&self) -> ListInstancePartitionsRequest
fn clone(&self) -> ListInstancePartitionsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ListInstancePartitionsRequest
impl Default for ListInstancePartitionsRequest
Sourcefn default() -> ListInstancePartitionsRequest
fn default() -> ListInstancePartitionsRequest
impl StructuralPartialEq for ListInstancePartitionsRequest