#[non_exhaustive]pub struct UpdateInstanceConfigRequest {
pub instance_config: Option<InstanceConfig>,
pub update_mask: Option<FieldMask>,
pub validate_only: bool,
/* private fields */
}Expand description
The request for UpdateInstanceConfig.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance_config: Option<InstanceConfig>Required. The user instance configuration to update, which must always include the instance configuration name. Otherwise, only fields mentioned in update_mask need be included. To prevent conflicts of concurrent updates, etag can be used.
update_mask: Option<FieldMask>Required. A mask specifying which fields in InstanceConfig should be updated. The field mask must always be specified; this prevents any future fields in InstanceConfig from being erased accidentally by clients that do not know about them. Only display_name and labels can be updated.
validate_only: boolAn option to validate, but not actually execute, a request, and provide the same response.
Implementations
Sourceimpl UpdateInstanceConfigRequest
impl UpdateInstanceConfigRequest
Sourcepub fn set_instance_config<T>(self, v: T) -> Selfwhere
T: Into<InstanceConfig>,
pub fn set_instance_config<T>(self, v: T) -> Selfwhere
T: Into<InstanceConfig>,
Sets the value of instance_config.
Example
use google_cloud_spanner_admin_instance_v1::model::InstanceConfig;
let x = UpdateInstanceConfigRequest::new().set_instance_config(InstanceConfig::default()/* use setters */);Sourcepub fn set_or_clear_instance_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<InstanceConfig>,
pub fn set_or_clear_instance_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<InstanceConfig>,
Sets or clears the value of instance_config.
Example
use google_cloud_spanner_admin_instance_v1::model::InstanceConfig;
let x = UpdateInstanceConfigRequest::new().set_or_clear_instance_config(Some(InstanceConfig::default()/* use setters */));
let x = UpdateInstanceConfigRequest::new().set_or_clear_instance_config(None::<InstanceConfig>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateInstanceConfigRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateInstanceConfigRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateInstanceConfigRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = UpdateInstanceConfigRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for UpdateInstanceConfigRequest
impl Clone for UpdateInstanceConfigRequest
Sourcefn clone(&self) -> UpdateInstanceConfigRequest
fn clone(&self) -> UpdateInstanceConfigRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateInstanceConfigRequest
impl Debug for UpdateInstanceConfigRequest
Sourceimpl Default for UpdateInstanceConfigRequest
impl Default for UpdateInstanceConfigRequest
Sourcefn default() -> UpdateInstanceConfigRequest
fn default() -> UpdateInstanceConfigRequest
impl StructuralPartialEq for UpdateInstanceConfigRequest